import javax.swing.*;
import java.awt.*;
import java.awt.event.*;
import java.text.DecimalFormat;

public class EuroKonverter extends JApplet {
	private Container cont = getContentPane();
	private JLabel eingabeLabel, ausgabeLabel;
	private JTextField eingabeFeld, ausgabeFeld;	
    private JButton konvert;

	private int richtung = 1;

	//Wird zum Erkennung berbreiter Ausgaben bentigt:
	private FontMetrics fm;
	private int maxAusgabeBreite;
	
	private JRadioButton euro2dm, dm2euro;
	private ButtonGroup rbGroup;

	private DecimalFormat form = new DecimalFormat("0.00");

    public void init() {
		cont.setLayout(null);

		// Dem Unicode-Zeichen \u27a0 entspricht ein horizontaler Pfeil. 
		dm2euro = new JRadioButton("DM "+'\u27a0'+" Euro", true);
   		dm2euro.setFocusable(false);

		euro2dm = new JRadioButton("Euro "+'\u27a0'+" DM", false);
   		euro2dm.setFocusable(false);
				
		rbGroup = new ButtonGroup();
		rbGroup.add(euro2dm);
		rbGroup.add(dm2euro);
		
		RadioHandler rbHandler = new RadioHandler();
		euro2dm.addItemListener(rbHandler);
		dm2euro.addItemListener(rbHandler);

		dm2euro.setBounds(5,15,100,20);
		euro2dm.setBounds(5,65,100,20);
		cont.add(dm2euro);
		cont.add(euro2dm);

		eingabeFeld = new JTextField("", 15);
   		eingabeFeld.requestFocus();
		eingabeFeld.setHorizontalAlignment(JTextField.RIGHT);
		eingabeFeld.setBounds(150,15,100,20);
		cont.add(eingabeFeld);

		eingabeLabel = new JLabel("DM");
		eingabeLabel.setBounds(255,15,45,20);
		cont.add(eingabeLabel);
		
		ausgabeFeld = new JTextField("", 15);
   		ausgabeFeld.setEditable(false);
   		ausgabeFeld.setFocusable(false);
   		ausgabeFeld.setHorizontalAlignment(JTextField.RIGHT);
		ausgabeFeld.setBounds(150,65,100,20);
		cont.add(ausgabeFeld);

		ausgabeLabel = new JLabel("Euro");
		ausgabeLabel.setBounds(255,65,45,20);
		cont.add(ausgabeLabel);

        konvert = new JButton("Konvertieren");
        konvert.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent e) {
          		String eingabe = eingabeFeld.getText(), ausgabe;
          		if (eingabe.length() == 0) {
          			konvert.transferFocus();
          			return;
          		}
          		double factor = 1.95583;
          		if (richtung == 0) {
          			factor = 1.95583;
          		}
          		else {
          			factor = 1.0/1.95583;
          		}
      			try {
					// Dies ermglicht die Eingabe des Kommas als Dezimaltrennzeichen:
	      			eingabe = eingabe.replace(',','.');
	      			double wert = Double.parseDouble(eingabe);
	      			wert *= factor;
	      			ausgabe = form.format(wert);
	      			if (fm.stringWidth(ausgabe) <= maxAusgabeBreite)
						ausgabeFeld.setText(ausgabe);
					else
						ausgabeFeld.setText("Ergebnis zu breit!");
      			} catch (Exception ex) {
					meldeFehler(ex);
      			}
				konvert.transferFocus();
				eingabeFeld.selectAll();
            }
        });
   		getRootPane().setDefaultButton(konvert);
		konvert.setBounds(5,120,290,25);
		cont.add(konvert, BorderLayout.SOUTH);
    }

    public void start() {
		//Wird zum Erkennung berbreiter Ausgaben bentigt:
		fm = getFontMetrics(getFont());
		maxAusgabeBreite = ausgabeFeld.getWidth();
		eingabeFeld.requestFocus();
	}

	private void meldeFehler(Exception ex) {
		JOptionPane.showMessageDialog(this, "Fehler bei der Konvertierung: "+
		ex.toString(), "Fehler", JOptionPane.ERROR_MESSAGE);
	}

	class RadioHandler implements ItemListener {
		public void itemStateChanged(ItemEvent e) {
			eingabeFeld.setText("");
			ausgabeFeld.setText("");
			if (e.getSource() == euro2dm) {
				eingabeLabel.setText("Euro");
				ausgabeLabel.setText("DM");
				richtung = 0;
			} else if (e.getSource() == dm2euro) {
				eingabeLabel.setText("DM");
				ausgabeLabel.setText("Euro");
				richtung = 1;
			}
		}
	}
}
