DROP DATABASE IF EXISTS Firma;

CREATE DATABASE IF NOT EXISTS Firma;

USE Firma;

DROP TABLE IF EXISTS Personal;
DROP TABLE IF EXISTS Kunden;
DROP TABLE IF EXISTS Auftraege;
DROP TABLE IF EXISTS Einsaetze;

CREATE TABLE Personal (
	PersNr INT NOT NULL AUTO_INCREMENT,
	Vorname VARCHAR (25) NOT NULL,
	Name VARCHAR (50) NOT NULL,
	Abteilung CHAR (1) NOT NULL,
	Strasse VARCHAR (40) NOT NULL,
	Hausnummer VARCHAR (5) NOT NULL,
	PLZ CHAR (5) NOT NULL,
	Ort VARCHAR (40) NOT NULL,
	Telefon VARCHAR(20) NOT NULL,
	Gehalt DOUBLE NOT NULL,
	PRIMARY KEY (PersNr)
) TYPE=INNODB;

CREATE TABLE Kunden (
	KundenNr INT NOT NULL AUTO_INCREMENT,
	Vorname VARCHAR (25) NOT NULL,
	Name VARCHAR (50) NOT NULL,
	Kategorie INT (2),
	Strasse VARCHAR (40) NOT NULL,
	Hausnummer VARCHAR (5) NOT NULL,
	PLZ CHAR (5) NOT NULL,
	Ort VARCHAR (40) NOT NULL,
	Telefon VARCHAR(20) NOT NULL,
	Kredit DOUBLE NOT NULL,
	PRIMARY KEY (KundenNr)
) TYPE=INNODB;

CREATE TABLE Auftraege (
	AuftragsNr INT NOT NULL AUTO_INCREMENT,
	KundenNr INT NOT NULL,
	Datum DATE NOT NULL,
	Erledigt INT NOT NULL,
	Bezahlt INT NOT NULL,
	PRIMARY KEY (AuftragsNr),
	INDEX (KundenNr),
	FOREIGN KEY (KundenNr) REFERENCES Kunden (KundenNr)
) TYPE=INNODB;

CREATE TABLE Einsaetze (
	EinsatzNr INT NOT NULL AUTO_INCREMENT,
	PersNr INT NOT NULL,
	AuftragsNr INT NOT NULL,
	Dauer DOUBLE NOT NULL,
	PRIMARY KEY (EinsatzNr),
	INDEX (PersNr),
	FOREIGN KEY (PersNr) REFERENCES Personal (PersNr), 
	INDEX (AuftragsNr),
	FOREIGN KEY (AuftragsNr) REFERENCES Auftraege (AuftragsNr)
) TYPE=INNODB;


INSERT INTO Personal (Vorname, Name, Abteilung, Strasse, Hausnummer, PLZ, Ort, Telefon, Gehalt) 
  VALUES ('Ulla', 'Schneider', 'B', 'Heide', '29', '51594', 'Raltop', '05123-12094', 1900.00);
INSERT INTO Personal (Vorname, Name, Abteilung, Strasse, Hausnummer, PLZ, Ort, Telefon, Gehalt) 
  VALUES ('Otto', 'Schmidt', 'A', 'Goethegasse', '12a','52292', 'Drohntal', '07319-78129', 2490.50);
INSERT INTO Personal (Vorname, Name, Abteilung, Strasse, Hausnummer, PLZ, Ort, Telefon, Gehalt) 
  VALUES ('Ludger', 'Mller', 'B', 'Hauptstrae', '45','53277', 'Urdorf', '04543-32212', 2260.33);
INSERT INTO Personal (Vorname, Name, Abteilung, Strasse, Hausnummer, PLZ, Ort, Telefon, Gehalt) 
  VALUES ('Emanuel', 'Fink', 'B', 'An der Ecke', '177','54822', 'Mondorf', '03423-73212', 1693.00);
INSERT INTO Personal (Vorname, Name, Abteilung, Strasse, Hausnummer, PLZ, Ort, Telefon, Gehalt) 
  VALUES ('Kurt', 'Schmidt', 'A', 'Sdstrasse', '23', '52292', 'Drohntal', '07319-53487', 2630.50);
INSERT INTO Personal (Vorname, Name, Abteilung, Strasse, Hausnummer, PLZ, Ort, Telefon, Gehalt) 
  VALUES ('Monika', 'Gerber', 'C', 'Mhlenstrae', '91', '51594', 'Raltop', '05123-78123', 2600.00);


INSERT INTO Kunden (Vorname, Name, Kategorie, Strasse, Hausnummer, PLZ, Ort, Telefon, Kredit) 
  VALUES ('Edgar', 'Eimer', 1, 'Andersweg', '7', '52434', 'Zweiweiler', '06342-13219', 5000.00);
INSERT INTO Kunden (Vorname, Name, Kategorie, Strasse, Hausnummer, PLZ, Ort, Telefon, Kredit) 
  VALUES ('Thomas', 'Thmmes', 2, 'Kieferschlund', '23', '52434', 'Zweiweiler', '06342-542712', 2000.00);
INSERT INTO Kunden (Vorname, Name, Kategorie, Strasse, Hausnummer, PLZ, Ort, Telefon, Kredit) 
  VALUES ('Ilse', 'Schulz', NULL, 'Oberer Waldweg', '25', '51434', 'Schnstadt', '062112-45398', 5000.00);
INSERT INTO Kunden (Vorname, Name, Kategorie, Strasse, Hausnummer, PLZ, Ort, Telefon, Kredit) 
  VALUES ('Lutz', 'Latz', NULL, 'Dorfplatz', '79', '51434', 'Schnstadt', '06342-123412', 2000.00);
INSERT INTO Kunden (Vorname, Name, Kategorie, Strasse, Hausnummer, PLZ, Ort, Telefon, Kredit) 
  VALUES ('Dorte', 'Lbke', 2, 'Andersweg', '56', '52434', 'Zweiweiler', '06342-77123', 3000.00);
INSERT INTO Kunden (Vorname, Name, Kategorie, Strasse, Hausnummer, PLZ, Ort, Telefon, Kredit) 
  VALUES ('Theo', 'Rost', 2, 'Kieferschlund', '55', '52434', 'Zweiweiler', '06342-67998', 5000.00);
INSERT INTO Kunden (Vorname, Name, Kategorie, Strasse, Hausnummer, PLZ, Ort, Telefon, Kredit) 
  VALUES ('Udo', 'Schmitt', 1, 'Oberer Waldweg', '82', '51434', 'Schnstadt', '062112-12546', 5000.00);
INSERT INTO Kunden (Vorname, Name, Kategorie, Strasse, Hausnummer, PLZ, Ort, Telefon, Kredit) 
  VALUES ('Karl', 'Lafer', 2, 'Dorfplatz', '120', '51434', 'Schnstadt', '06342-33418', 2000.00);


INSERT INTO Auftraege (KundenNr, Datum, Erledigt, Bezahlt) VALUES (1, '2006-03-01', 1, 0);
INSERT INTO Auftraege (KundenNr, Datum, Erledigt, Bezahlt) VALUES (1, '2006-03-03', 0, 0);
INSERT INTO Auftraege (KundenNr, Datum, Erledigt, Bezahlt) VALUES (2, '2006-03-13', 0, 0);
INSERT INTO Auftraege (KundenNr, Datum, Erledigt, Bezahlt) VALUES (2, '2006-03-15', 0, 0);
INSERT INTO Auftraege (KundenNr, Datum, Erledigt, Bezahlt) VALUES (2, '2006-04-15', 0, 0);
INSERT INTO Auftraege (KundenNr, Datum, Erledigt, Bezahlt) VALUES (4, '2006-04-22', 1, 0);
INSERT INTO Auftraege (KundenNr, Datum, Erledigt, Bezahlt) VALUES (5, '2006-04-26', 1, 0);
INSERT INTO Auftraege (KundenNr, Datum, Erledigt, Bezahlt) VALUES (6, '2006-04-28', 0, 0);
INSERT INTO Auftraege (KundenNr, Datum, Erledigt, Bezahlt) VALUES (7, '2006-05-02', 0, 0);
INSERT INTO Auftraege (KundenNr, Datum, Erledigt, Bezahlt) VALUES (8, '2006-05-03', 0, 0);

INSERT INTO Einsaetze (PersNr, AuftragsNr, Dauer) VALUES (1, 2, 6.5);
INSERT INTO Einsaetze (PersNr, AuftragsNr, Dauer) VALUES (4, 2, 4);
INSERT INTO Einsaetze (PersNr, AuftragsNr, Dauer) VALUES (2, 1, 7);
INSERT INTO Einsaetze (PersNr, AuftragsNr, Dauer) VALUES (3, 1, 7);
INSERT INTO Einsaetze (PersNr, AuftragsNr, Dauer) VALUES (4, 4, 8);
INSERT INTO Einsaetze (PersNr, AuftragsNr, Dauer) VALUES (2, 2, 2.75);
INSERT INTO Einsaetze (PersNr, AuftragsNr, Dauer) VALUES (1, 3, 8);
INSERT INTO Einsaetze (PersNr, AuftragsNr, Dauer) VALUES (3, 1, 1.5);
INSERT INTO Einsaetze (PersNr, AuftragsNr, Dauer) VALUES (5, 5, 3);
INSERT INTO Einsaetze (PersNr, AuftragsNr, Dauer) VALUES (5, 6, 2);
INSERT INTO Einsaetze (PersNr, AuftragsNr, Dauer) VALUES (6, 7, 8);
INSERT INTO Einsaetze (PersNr, AuftragsNr, Dauer) VALUES (5, 8, 4);
INSERT INTO Einsaetze (PersNr, AuftragsNr, Dauer) VALUES (6, 9, 6);
INSERT INTO Einsaetze (PersNr, AuftragsNr, Dauer) VALUES (6, 10,2);
