import java.net.*;
import java.io.*;
import java.util.*;
import java.util.zip.*;
import java.text.*;

public class SoUp {
	private String parFile;		// Name der Parameterdatei
	private String soDir;		// lokales Sophos-Inst.-Verz. von
	private String soVer;		// lokal inst. Sophos-Version
	private String soVerNum;	// lokal inst. Sophos-Version, ohne Punkt
	private String soDate;		// Datum der lokal vorhandenen ZIP-Datei
	private String fileName;	// lokaler Name der heruntergeladenen ZIP-Datei

	public SoUp() {
		System.out.println("Sophos-IDE-Checker 0.9");
		System.out.println("Bernhard Baltes-Goetz, URT\n");
	}

	public void readParameter(String[] args) {
		File file = new File("SoUp.txt");
		if (!file.exists()) {
			if (args.length == 0)
				error("Die Parameterdatei muss sich unter dem Namen SoUp.txt im aktuellen Verzeichnis befinden,"
					+"\noder es muss im Startkommando ein Dateinamen angegeben werden: java SoUp <Pfad der Parameterdatei>.");
			else {
				file = new File(args[0]);
				if (!file.exists())
					error("Parameterdatei nicht gefunden.");
			}
		}
		parFile = file.getName();
		try {
			BufferedReader br = new BufferedReader(new FileReader(file));
			String line;
			while((line = br.readLine()) != null) {
				int soDirPos = line.indexOf("soDir=");
				if (soDirPos >= 0)
					soDir = line.substring(soDirPos+6,line.length());
				int soVerPos = line.indexOf("soVer=");
				if (soVerPos >= 0)
					soVer = line.substring(soVerPos+6,line.length());
				int soDatePos = line.indexOf("soDate=");
				if (soDatePos >= 0)
					soDate = line.substring(soDatePos+7,line.length());
			}

			if (soDir == null)
				error("Kein Sophos-Verz. in der Parameterdatei");
			if (soVer == null)
				error("Keine Sophos-Version in der Parameterdatei");
			if (soDate == null)
				soDate="01.01.1970 00:00:00";

			br.close();

			int pos = soVer.indexOf(".");
			if (pos < 0)
				error("Bitte Versionsangabe nach dem Muster n.nn");
			soVerNum = soVer.substring(0,pos)+soVer.substring(pos+1,soVer.length());

			fileName = String.valueOf(soVerNum)+"_ides.zip";
			
			System.out.println("\nEs wurden folgende Parameter aus der Datei "+parFile+" gelesen:");
			System.out.println("  Sophos-Inst.verz.:\t"+soDir);
			System.out.println("  Sophos-Version:\t"+soVer);
			System.out.println("  IDEs zuletzt akt.:\t"+soDate);

		} catch (Exception e) {
			error("Fehler in readParameter:\n"+e.toString());
		}
	}

	public  void writeParameter() {
		try {
			PrintWriter pw = new PrintWriter(new FileWriter(parFile));
			pw.println("soDir="+soDir);
			pw.println("soVer="+soVer);
			pw.println("soDate="+soDate);
			pw.close();
		} catch (Exception e) {
			error("Fehler in writeParameter:\n"+e.toString());
		}
	}

	private  void error(String s) {
		System.out.println(((char) 7)+"\nFehler:\n  "+s);
		try {
			System.out.println("\n\nBeenden mit Enter");
			System.in.read();
		} catch (Exception e) {}
		System.exit(1);
	}

	private  void end() {
		try {
			System.out.println("\n\nBeenden mit Enter");
			System.in.read();
		} catch (Exception e) {}
		System.exit(0);
	}


	public  void get() {
		try {
			String urlString = "http://www.sophos.com/downloads/ide/"+fileName;
			DateFormat df = DateFormat.getDateTimeInstance();

			URL url = new URL(urlString);
			URLConnection urlConn = url.openConnection();
			System.out.println("\n\nDie Verbindung mit dem Sophos-Server wird hergestellt.\n");
			urlConn.connect();

			if (urlConn.getContentLength() < 0) {
				System.out.println("\nFuer die Sophos-Version "+soVer+" sind keine ergaenzenden Virendefinitionen");
				System.out.println("verfuegbar. Eventuell muessen Sie eine neue Sophos-Version installieren");
				end();
			}

			System.out.println("\nInformationen zu "+urlString+":");
			System.out.println("  Groesse in Bytes:\t"+urlConn.getContentLength());
//			System.out.println("  Expiration:\t\t"+df.format(new Date(urlConn.getExpiration())));
			System.out.println("  Letzte Aenderung:\t"+df.format(new Date(urlConn.getLastModified()))+"\n"); 

			if (df.format(new Date(urlConn.getLastModified())).equals(soDate)) {
				System.out.println("\nLaut Parameterdatei sind die Virendefinitionen auf aktuellen Stand.");
				end();
			}

			if (urlConn.getContentLength() > 0) {
				soDate = df.format(new Date(urlConn.getLastModified()));
				System.out.println("\nDie Datei\n  "+urlString+"\nwird herunter geladen in das Verzeichnis\n  "+soDir);
				BufferedInputStream in = new BufferedInputStream(urlConn.getInputStream());
				BufferedOutputStream out = new BufferedOutputStream(new FileOutputStream(soDir+fileName));
				int i;
				while ((i = in.read()) != -1)
					out.write(i);
				out.flush();
			}

		} catch (Exception e) {
			e.printStackTrace();
			error("Fehler in get:\n"+e.toString());
		}
	}

	public  void unpack() {
		try {
			ZipFile zip = new ZipFile(soDir+fileName);
			ZipEntry entry;
			Enumeration e = zip.entries();
			BufferedInputStream bis; 
			BufferedOutputStream bos;
			System.out.println("\nDie IDE-Dateien werden ausgepackt:");
			int n = 0;
			while (e.hasMoreElements()) {
				entry = (ZipEntry) e.nextElement();
				bis = new BufferedInputStream(zip.getInputStream(entry));
				bos = new BufferedOutputStream(new FileOutputStream(soDir+entry.getName()));
				int i;
				while ((i = bis.read()) != -1)
					bos.write(i);
				bos.close();
				n++;
				System.out.println("  "+soDir+entry.getName());
			}
			System.out.println("\nEs wurden "+n+" Dateien ausgepackt.\n\nUm die neuen Definitionen zu aktivieren, muss der Rechner neu gestartet werden!");
		} catch (Exception e) {
			error("Fehler in unpack:\n"+e.toString());
		}
	}

	public static void main(String[] args) {
		SoUp soup = new SoUp();		
		soup.readParameter(args);
		soup.get();
		soup.unpack();
		soup.writeParameter();
		soup.end();
	}
}
